@@ -8,7 +8,7 @@
 #        .
 #          .
 #
-#	SCCS: @(#)Expression.pm	1.36 03/27/15 13:11:31
+#	SCCS: @(#)Expression.pm	1.37 03/27/15 15:46:37
 #
 # This module is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself. You must preserve this entire copyright
@@ -50,7 +50,7 @@ use vars qw/
 	$Version
 );
 
-our $VERSION = "1.36";
+our $VERSION = "1.37";
 
 # Fundamental to this is a tree of nodes.
 # Nodes are hashes with members:
@@ -912,20 +912,39 @@ Math::Expression - Safely evaluate arithmetic/string expressions
 
 =head1 SYNOPSIS
 
-  use strict;
-  use Math::Expression;
+Shipping cost depends on item price by some arbitrary formula. The VAT amount can also
+vary depending on political edict. Rather than nail these formula into the application code the
+formula are obtained at run time from some configuration source. These formula are probably
+entered by a non technical manager and are thus not to be trusted.
 
-  my $ArithEnv = new Math::Expression;
+    use Math::Expression;
+    my $ae = new Math::Expression;
 
-  # Some/all of these read from a config file:
-  my $tree1 = $ArithEnv->Parse('ConfVar := 42');
+# Obtain from a configuration source:
+    my $ShippingFormula = 'Price >= 100 ? Price * 0.1 : (Price >= 50 ? Price * 0.15 : Price * 0.2)';
+    my $VatFormula = 'VatTax := Price * 0.2';
 
-  my $tree2 = $ArithEnv->Parse('ConfVar * 3');
+# Price of what you are selling, set the price variable:
+    my $price = 100;
+    $ae->VarSetScalar('Price', $price);
 
-  ...
+# Obtain VAT & Shipping using the configured formula:
+    my $VatTax = $ae->ParseToScalar($VatFormula);
+    my $Shipping  = $ae->ParseToScalar($ShippingFormula);
+
+    say "Price=$price VatTax=$VatTax Shipping=$Shipping";
+
+# If these will be run many times, parse the formula once:
+
+    my $VatExpr = $ae->Parse($VatFormula);
+    my $ShipExpr = $ae->Parse($ShippingFormula);
+
+# Evaluate it with the current price many times:
+
+    $ae->VarSetScalar('Price', $price);
+    $VatTax = $ae->EvalToScalar($VatExpr);
+    $Shipping = $ae->EvalToScalar($ShipExpr);
 
-  $ArithEnv->Eval($tree1);
-  my $ConfValue = $ArithEnv->EvalToScalar($tree2);
 
 =head1 DESCRIPTION
 
@@ -1405,7 +1424,7 @@ Alain D D Williams <addw@phcomp.co.uk>
 
 =head2 Copyright and Version
 
-Version "1.36", this is available as: $Math::Expression::Version.
+Version "1.37", this is available as: $Math::Expression::Version.
 
 Copyright (c) 2003, 2015 Parliament Hill Computers Ltd/Alain D D Williams. All rights reserved.
 This program is free software; you can redistribute it and/or modify it
